@@ -15,8 +15,6 @@ from sentry_sdk.integrations.celery.beat import (
 from sentry_sdk.integrations.celery.utils import _now_seconds_since_epoch
 from sentry_sdk.integrations.logging import ignore_logger
 from sentry_sdk.tracing import BAGGAGE_HEADER_NAME, TRANSACTION_SOURCE_TASK
-from sentry_sdk._types import TYPE_CHECKING
-from sentry_sdk.scope import Scope
 from sentry_sdk.tracing_utils import Baggage
 from sentry_sdk.utils import (
     capture_internal_exceptions,
@@ -25,6 +23,8 @@ from sentry_sdk.utils import (
     reraise,
 )
 
+from typing import TYPE_CHECKING
+
 if TYPE_CHECKING:
     from typing import Any
     from typing import Callable
@@ -41,6 +41,7 @@ if TYPE_CHECKING:
 
 try:
     from celery import VERSION as CELERY_VERSION  # type: ignore
+    from celery.app.task import Task  # type: ignore
     from celery.app.trace import task_has_custom
     from celery.exceptions import (  # type: ignore
         Ignore,
@@ -83,6 +84,7 @@ class CeleryIntegration(Integration):
 
         _patch_build_tracer()
         _patch_task_apply_async()
+        _patch_celery_send_task()
         _patch_worker_exit()
         _patch_producer_publish()
 
@@ -100,7 +102,7 @@ class CeleryIntegration(Integration):
 def _set_status(status):
     # type: (str) -> None
     with capture_internal_exceptions():
-        scope = Scope.get_current_scope()
+        scope = sentry_sdk.get_current_scope()
         if scope.span is not None:
             scope.span.set_status(status)
 
@@ -170,7 +172,7 @@ def _update_celery_task_headers(original_headers, span, monitor_beat_tasks):
         # if span is None (when the task was started by Celery Beat)
         # this will return the trace headers from the scope.
         headers = dict(
-            Scope.get_isolation_scope().iter_trace_propagation_headers(span=span)
+            sentry_sdk.get_isolation_scope().iter_trace_propagation_headers(span=span)
         )
 
         if monitor_beat_tasks:
@@ -243,7 +245,7 @@ class NoOpMgr:
         return None
 
 
-def _wrap_apply_async(f):
+def _wrap_task_run(f):
     # type: (F) -> F
     @wraps(f)
     @ensure_integration_enabled(CeleryIntegration, f)
@@ -260,16 +262,19 @@ def _wrap_apply_async(f):
         if not propagate_traces:
             return f(*args, **kwargs)
 
-        task = args[0]
+        if isinstance(args[0], Task):
+            task_name = args[0].name  # type: str
+        elif len(args) > 1 and isinstance(args[1], str):
+            task_name = args[1]
+        else:
+            task_name = "<unknown Celery task>"
 
-        task_started_from_beat = (
-            sentry_sdk.Scope.get_isolation_scope()._name == "celery-beat"
-        )
+        task_started_from_beat = sentry_sdk.get_isolation_scope()._name == "celery-beat"
 
         span_mgr = (
             sentry_sdk.start_span(
                 op=OP.QUEUE_SUBMIT_CELERY,
-                description=task.name,
+                description=task_name,
                 origin=CeleryIntegration.origin,
             )
             if not task_started_from_beat
@@ -439,9 +444,14 @@ def _patch_build_tracer():
 
 def _patch_task_apply_async():
     # type: () -> None
-    from celery.app.task import Task  # type: ignore
+    Task.apply_async = _wrap_task_run(Task.apply_async)
 
-    Task.apply_async = _wrap_apply_async(Task.apply_async)
+
+def _patch_celery_send_task():
+    # type: () -> None
+    from celery import Celery
+
+    Celery.send_task = _wrap_task_run(Celery.send_task)
 
 
 def _patch_worker_exit():
