@@ -5,10 +5,9 @@ import weakref
 from importlib import import_module
 
 import sentry_sdk
-from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.consts import OP, SPANDATA
 from sentry_sdk.db.explain_plan.django import attach_explain_plan_to_span
-from sentry_sdk.scope import Scope, add_global_event_processor, should_send_default_pii
+from sentry_sdk.scope import add_global_event_processor, should_send_default_pii
 from sentry_sdk.serializer import add_global_repr_processor
 from sentry_sdk.tracing import SOURCE_FOR_STYLE, TRANSACTION_SOURCE_URL
 from sentry_sdk.tracing_utils import add_query_source, record_sql_queries
@@ -68,6 +67,7 @@ if DJANGO_VERSION[:2] > (1, 8):
 else:
     patch_caching = None  # type: ignore
 
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from typing import Any
@@ -371,7 +371,7 @@ def _patch_django_asgi_handler():
 
 
 def _set_transaction_name_and_source(scope, transaction_style, request):
-    # type: (Scope, str, WSGIRequest) -> None
+    # type: (sentry_sdk.Scope, str, WSGIRequest) -> None
     try:
         transaction_name = None
         if transaction_style == "function_name":
@@ -419,7 +419,7 @@ def _before_get_response(request):
 
     _patch_drf()
 
-    scope = Scope.get_current_scope()
+    scope = sentry_sdk.get_current_scope()
     # Rely on WSGI middleware to start a trace
     _set_transaction_name_and_source(scope, integration.transaction_style, request)
 
@@ -429,7 +429,7 @@ def _before_get_response(request):
 
 
 def _attempt_resolve_again(request, scope, transaction_style):
-    # type: (WSGIRequest, Scope, str) -> None
+    # type: (WSGIRequest, sentry_sdk.Scope, str) -> None
     """
     Some django middlewares overwrite request.urlconf
     so we need to respect that contract,
@@ -448,7 +448,7 @@ def _after_get_response(request):
     if integration.transaction_style != "url":
         return
 
-    scope = Scope.get_current_scope()
+    scope = sentry_sdk.get_current_scope()
     _attempt_resolve_again(request, scope, integration.transaction_style)
 
 
@@ -518,7 +518,7 @@ def _got_request_exception(request=None, **kwargs):
     integration = client.get_integration(DjangoIntegration)
 
     if request is not None and integration.transaction_style == "url":
-        scope = Scope.get_current_scope()
+        scope = sentry_sdk.get_current_scope()
         _attempt_resolve_again(request, scope, integration.transaction_style)
 
     event, hint = event_from_exception(
