@@ -3,7 +3,6 @@ from copy import deepcopy
 from functools import wraps
 
 import sentry_sdk
-from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.integrations import DidNotEnable
 from sentry_sdk.scope import should_send_default_pii
 from sentry_sdk.tracing import SOURCE_FOR_STYLE, TRANSACTION_SOURCE_ROUTE
@@ -12,6 +11,8 @@ from sentry_sdk.utils import (
     logger,
 )
 
+from typing import TYPE_CHECKING
+
 if TYPE_CHECKING:
     from typing import Any, Callable, Dict
     from sentry_sdk._types import Event
