@@ -2,11 +2,10 @@ import sys
 from datetime import datetime
 
 import sentry_sdk
-from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.api import continue_trace, get_baggage, get_traceparent
 from sentry_sdk.consts import OP, SPANSTATUS
 from sentry_sdk.integrations import DidNotEnable, Integration
-from sentry_sdk.scope import Scope, should_send_default_pii
+from sentry_sdk.scope import should_send_default_pii
 from sentry_sdk.tracing import (
     BAGGAGE_HEADER_NAME,
     SENTRY_TRACE_HEADER_NAME,
@@ -20,6 +19,8 @@ from sentry_sdk.utils import (
     reraise,
 )
 
+from typing import TYPE_CHECKING
+
 if TYPE_CHECKING:
     from typing import Any, Callable, Optional, Union, TypeVar
 
@@ -106,7 +107,7 @@ def _make_event_processor(task):
 
 def _capture_exception(exc_info):
     # type: (ExcInfo) -> None
-    scope = Scope.get_current_scope()
+    scope = sentry_sdk.get_current_scope()
 
     if exc_info[0] in HUEY_CONTROL_FLOW_EXCEPTIONS:
         scope.transaction.set_status(SPANSTATUS.ABORTED)
@@ -115,7 +116,7 @@ def _capture_exception(exc_info):
     scope.transaction.set_status(SPANSTATUS.INTERNAL_ERROR)
     event, hint = event_from_exception(
         exc_info,
-        client_options=Scope.get_client().options,
+        client_options=sentry_sdk.get_client().options,
         mechanism={"type": HueyIntegration.identifier, "handled": False},
     )
     scope.capture_event(event, hint=hint)
