@@ -1,6 +1,6 @@
 from datetime import datetime, timezone
 from time import time
-from typing import cast
+from typing import TYPE_CHECKING, cast
 
 from opentelemetry.context import get_value
 from opentelemetry.sdk.trace import SpanProcessor, ReadableSpan as OTelSpan
@@ -16,7 +16,7 @@ from opentelemetry.trace.span import (
     INVALID_TRACE_ID,
 )
 from sentry_sdk import get_client, start_transaction
-from sentry_sdk.consts import INSTRUMENTER
+from sentry_sdk.consts import INSTRUMENTER, SPANSTATUS
 from sentry_sdk.integrations.opentelemetry.consts import (
     SENTRY_BAGGAGE_KEY,
     SENTRY_TRACE_KEY,
@@ -24,7 +24,6 @@ from sentry_sdk.integrations.opentelemetry.consts import (
 from sentry_sdk.scope import add_global_event_processor
 from sentry_sdk.tracing import Transaction, Span as SentrySpan
 from sentry_sdk.utils import Dsn
-from sentry_sdk._types import TYPE_CHECKING
 
 from urllib3.util import parse_url as urlparse
 
@@ -299,10 +298,10 @@ class SentrySpanProcessor(SpanProcessor):
             return
 
         if otel_span.status.is_ok:
-            sentry_span.set_status("ok")
+            sentry_span.set_status(SPANSTATUS.OK)
             return
 
-        sentry_span.set_status("internal_error")
+        sentry_span.set_status(SPANSTATUS.INTERNAL_ERROR)
 
     def _update_span_with_otel_data(self, sentry_span, otel_span):
         # type: (SentrySpan, OTelSpan) -> None
